@@ -28,9 +28,13 @@ class LiquidityProviderAgent(AgentBase):
             super().__init__(unique_id, pos, model, moore=moore)
 
 
-    def deposit(self, tkn, amount, block_num=0):
+    def deposit(self, tkn, amount, block_num=0, fake_wallet=True):
+
+        if fake_wallet:
+            self.handle_fake_wallet(tkn, amount, m=1000)
+        else:
+            self.wallet[f'bn{tkn}'] = [0]
 
-        self.handle_fake_wallet(tkn, amount, m=1000)
         for key in self.wallet:
             if (tkn == key) & (tkn == 'BNT'):
                 self.wallet[tkn].append(self.wallet[tkn][-1] - amount)
@@ -45,10 +49,15 @@ class LiquidityProviderAgent(AgentBase):
             elif key == 'block_num':
                 self.wallet[key].append(self.wallet[key][-1])
 
+            if (key != 'block_num') & (self.wallet[key][-1] < 0):
+                if not self.protocol.warning_only:
+                    raise UserWarning(f'Error. {key} balance cannot be less than zero. {self.wallet[key][-1]}')
+
+
         if len(self.wallet['BNT']) < len(self.wallet[tkn]):
             self.wallet['BNT'].append(self.wallet['BNT'][-1])
 
-    def withdraw(self, tkn, amount, block_num=0):
+    def withdraw(self, tkn, amount, block_num=0, fake_wallet=True):
         '''
         Loops over the addresses and discovers a random user with a non-zero balance of a random TKN (TKN).
         (conditional logic removes the blockNo and bnTKN lists from the choice)
@@ -56,7 +65,11 @@ class LiquidityProviderAgent(AgentBase):
         Adds new rows for each address, subtracts x from the appropriate list (i.e. as though the user has transferred it to the vault).
         Calls the AddLiquidity function, and adds the appropriate number of pool tokens to the appropriate list in the addresses dictionary.
         '''
-        self.handle_fake_wallet(tkn, amount, m=0)
+        if fake_wallet:
+            self.handle_fake_wallet(tkn, amount, m=0)
+        else:
+            self.wallet[f'bn{tkn}'] = [0]
+
         if 'BNT' not in self.wallet:
             self.wallet['BNT'] = [0 for i in range(len(self.wallet[tkn]))]
 
@@ -73,6 +86,11 @@ class LiquidityProviderAgent(AgentBase):
                 if len(self.wallet[key]) < len(self.wallet[tkn]):
                     self.wallet[key].append(self.wallet[key][-1])
 
+            if (key != 'block_num') & (self.wallet[key][-1] < 0):
+                if not self.protocol.warning_only:
+                    raise UserWarning(f'Error. {key} balance cannot be less than zero. {self.wallet[key][-1]}')
+
+
         if len(self.wallet['block_num']) < len(self.wallet[tkn]):
             self.wallet['block_num'].append(block_num)
         if len(self.wallet['BNT']) < len(self.wallet[tkn]):
@@ -84,6 +102,7 @@ class LiquidityProviderAgent(AgentBase):
             self.wallet[f'bn{tkn}']=[0 for i in range(len(self.wallet['block_num']))]
             if tkn == 'BNT':
                 self.wallet[f'v{tkn}'] = [0 for i in range(len(self.wallet['block_num']))]
+
         if 'BNT' not in self.wallet:
             self.wallet['BNT'] = [0 for i in range(len(self.wallet['block_num']))]
 
