@@ -24,6 +24,7 @@ class Bancor3(EnvBase):
     ema = {
         'TKN': {'block_num': [0], 'ema': [0]},
         'BNT': {'block_num': [0], 'ema': [0]},
+        'DAI': {'block_num': [0], 'ema': [0]},
         'wBTC': {'block_num': [0], 'ema': [0]},
         'ETH': {'block_num': [0], 'ema': [0]},
         'LINK': {'block_num': [0], 'ema': [0]}
@@ -34,7 +35,7 @@ class Bancor3(EnvBase):
             block_num=0,
             alpha=0.2,
             is_solidity=False,
-            min_liquidity_threshold=1000,
+            min_liquidity_threshold=10000,
             exit_fee=.0025,
             cooldown_period=7,
             bnt_funding_limit=100000,
@@ -48,16 +49,19 @@ class Bancor3(EnvBase):
                         "ETH": {'block_num': [0, 1, 2, 3],
                                 'price_usd': [2550.00, 2400.00, 2450.00, 2500.00]},
                         "wBTC": {'block_num': [0, 1, 2, 3],
-                                'price_usd': [40123.23, 40312.21, 40111.11, 40000.00]}
+                                'price_usd': [40123.23, 40312.21, 40111.11, 40000.00]},
+                        "DAI": {'block_num': [0, 1, 2, 3],
+                                'price_usd': [1.0, 1.0, 1.0, 1.00]}
             },
             pool_fees={
                 "TKN": 0.01,
                 "BNT": 0.01,
                 "LINK": 0.01,
                 "ETH": 0.01,
-                "wBTC": 0.01
+                "wBTC": 0.01,
+                "DAI": 0.01,
             },
-            whitelisted_tokens=[],
+            whitelisted_tokens=['wBTC','BNT','LINK','ETH','DAI','TKN'],
             bootstrapped_tokens=[],
             exchange_rates={},
             spot_prices={
@@ -70,14 +74,17 @@ class Bancor3(EnvBase):
                 "ETH": {'block_num':[0],
                         'price_usd':[2500.00]},
                 "wBTC": {'block_num':[0],
-                        'price_usd':[40000.00]}
+                        'price_usd':[40000.00]},
+                "DAI": {'block_num': [0],
+                         'price_usd': [1.00]}
             },
             vortex_rates={
                 "TKN": 0.2,
                 "BNT": 0.2,
                 "LINK": 0.2,
                 "ETH": 0.2,
-                "wBTC": 0.2
+                "wBTC": 0.2,
+                "DAI": 0.2,
             },
             warning_only=False,
             dao_msig_initialized_pools=[],
@@ -133,7 +140,7 @@ class Bancor3(EnvBase):
             a, b, c, e, m, n, x, w = self.validate_input_types(tkn, x)
 
             # check balanced
-            self.tokenomics.check_balanced(b, c, e, n)
+            self.tokenomics.check_balanced(c)
 
             if self.tokenomics.is_balanced:
                 case = 'bootstrap surplus'
