@@ -6,8 +6,9 @@ class FloatingPointTokenomics(TokenomicsBase):
     """Tokenomics subclass for all floating-point arithmetic.
     """
 
-    def check_balanced(self, b, c, e, n, is_surplus=False, is_deficit=True, case='check surplus', is_balanced=False):
-        if (b + c) / (1 - n) == e: is_balanced, is_deficit, is_surplus = True, False, False
+    def check_balanced(self, c, is_surplus=False, is_deficit=True, is_balanced=False):
+        if c == 0:
+            is_balanced, is_deficit, is_surplus = True, False, False
         self.is_balanced, self.surplus, self.deficit, self.hlim, self.satisfies_hlim, self.hmax, self.satisfies_hmax = is_balanced, is_surplus, is_deficit, np.nan, np.nan, np.nan, np.nan
 
     def check_surplus(self, b, c, e, n, is_surplus=False, is_deficit=True, case='check surplus'):
